# Dependecy check example

## Parameters

| Argument | Description                          |
| :------- | :--------------------------- |
| -v       | Prints Dependency Check version and exit  |
| without parameters | Scans the current directory (must be a git repo) |


## Detect outdated dependencies in the current project using [OWASP DependencyCheck](https://www.owasp.org/index.php/OWASP_Dependency_Check)

- One 'analysis' stage with one job  
- Allows the job to fail without impacting the rest of the CI (allow_failure: true)
- Export the results as an artifact


``` yml
stages:
  - analysis 
dependency_check:
  stage: analysis
  image: 
    name: its-registry.unl.edu/unl-its/docker-ci/dependency-check
  variables:
    DEPENDENCY_CHECK_OUT_DIR: ./dependency_check_results/
  tags:
    - docker
  script:
    - dependency-check --format ALL -s ./ --out ${DEPENDENCY_CHECK_OUT_DIR} --project ${CI_PROJECT_NAMESPACE}
  artifacts:
    paths:
      - ./dependency_check_results/dependency-check-report.html
      - ./dependency_check_results/dependency_check_results/dependency-check-report.xml
    expire_in: 1 day
  allow_failure: true
``` 

## Scan the current directory (must be a git repo)

``` bash
CI_PROJECT_NAMESPACE=`basename $(git rev-parse --show-toplevel)`
docker run -it --rm -v "${PWD}:/work" -w /work -e CI_PROJECT_NAMESPACE=${CI_PROJECT_NAMESPACE} its-registry.unl.edu/unl-its/docker-ci/dependency-check dependency-check --format ALL -s ./ --out ./dependency_check_results --project ${CI_PROJECT_NAMESPACE}
```
